import greenfoot.*;

import java.util.List;
import java.util.ArrayList;

/**
 * Vehicle. This is the base class for all vehicles. In addition to the standard Actor
 * methods, it provides the ability to move and turn.  Based on the Animal class in the
 * little-crab scenario (written by Michael Kolling).
 * 
 * @author Adrienne Decker
 * @version 1.0
 */
public class Vehicle extends Actor
{
    private static final double WALKING_SPEED = 25.0;
    
    /**
     * Constructor for Animal - nothing to do.
     */
    public Vehicle()
    {
    }

    /**
     * Act - empty method. Animals have no default action.
     */
    public void act()
    {
    }
    
    
    /**
     * Turn 'angle' degrees towards the right (clockwise).
     */
    public void turn(int angle)
    {
        setRotation(getRotation() + angle);
    }
    

    /**
     * Move forward in the current direction.
     */
    public void move()
    {
        double angle = Math.toRadians( getRotation() );
        int x = (int) Math.round(getX() + Math.cos(angle) * WALKING_SPEED);
        int y = (int) Math.round(getY() + Math.sin(angle) * WALKING_SPEED);
        
        setLocation(x, y);
    }

    
    /**
     * Test if we are close to one of the edges of the world. Return true is we are.
     */
    public boolean atWorldEdge()
    {
        if(getX() < 20 || getX() > getWorld().getWidth() - 20)
            return true;
        if(getY() < 20 || getY() > getWorld().getHeight() - 20)
            return true;
        else
            return false;
    }
    
    
    /**
     * Return true if we can see an object of class 'clss' right where we are. 
     * False if there is no such object here.
     */
    public boolean canSee(Class clss)
    {
        Actor actor = getOneObjectAtOffset(0, 0, clss);
        return actor != null;        
    }

}